@@ -1,7 +1,7 @@
 """
 Type annotations for mediatailor service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/type_defs/)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence, Union
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AccessTypeType,
     ChannelStateType,
